import { select } from 'd3';
import { viz } from './viz';
import { data } from '@drbagwell/daily-surface-air-temperature';
import { observeResize } from '@drbagwell/responsive-viz-axes';

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;

  const { width, height } = dimensions;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  viz(svg, {
    data,
    xValue: (d) => d.day_of_year,
    xAxisLabelText: 'Year',
    xAxisLabelOffset: 35,
    yValue: (d) => +d.airTemp,
    lineValue: (d) => d.year,
    yAxisLabelText: 'Air Temperature',
    yAxisLabelOffset: 20,
    circleRadius: 500 / 100,
    lineOpacity: 725 / 1000,
    marginTop: 0,
    marginRight: 50,
    marginBottom: 50,
    marginLeft: 50,
    width,
    height,
    innerRectFill: '#B5B5B5',
  });
};
