import {
  scaleLinear,
  scaleSequential,
  scaleTime,
  flatGroup,
  line,
  extent,
  interpolateTurbo,
} from 'd3';
import { axes } from '@drbagwell/responsive-viz-axes';

export const viz = (
  svg,
  {
    data,
    xValue,
    xAxisLabelText,
    xAxisLabelOffset,
    yValue,
    yAxisLabelText,
    yAxisLabelOffset,
    lineValue,
    marginLeft,
    marginTop,
    marginRight,
    marginBottom,
    width,
    height,
    circleRadius,
    lineOpacity,
    innerRectFill,
  },
) => {
  const xScale = scaleTime(extent(data, xValue), [
    marginLeft,
    width - marginRight,
  ]);

  const yScale = scaleLinear(extent(data, yValue), [
    height - marginBottom,
    marginTop,
  ]);

  const colorScale = scaleSequential(
    extent(data, lineValue),
    interpolateTurbo,
  );

  const innerWidth = width - marginLeft - marginRight;
  const innerHeight = height - marginTop - marginBottom;

  // initial Canvas Drawing Region
  svg
    .selectAll('rect')
    .data([null])
    .join('rect')
    .attr('x', marginLeft)
    .attr('y', marginTop)
    .attr('width', innerWidth)
    .attr('height', innerHeight)
    .attr('fill', innerRectFill);

  axes(svg, {
    width,
    height,
    xScale,
    xAxisLabelOffset,
    xAxisLabelText,
    yScale,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginBottom,
  });

  const lineGenerator = line(
    (d) => xScale(xValue(d)),
    (d) => yScale(yValue(d)),
  ).defined(yValue);

  const dataGrouped = flatGroup(data, lineValue);

  //  Multiple lines. One for each group
  svg
    .selectAll('path.mark')
    .data(dataGrouped)
    .join('path')
    .attr('class', 'mark')
    .attr('fill', 'none')
    .attr('stroke', 'black')
    .attr('opacity', (d) => (d[0] === 2024 ? 1 : 0.3))
    .attr('stroke-width', (d) => {
      if (d[0] === 2024) return 3;
      return 1;
    })
    .attr('stroke', (d) => {
      if (d[0] === 2024) return 'red';
      return colorScale(d[0]);
    })
    .attr('d', (d) => lineGenerator(d[1]));
};
